@@ -143,46 +143,6 @@ GFile *user_bfdir(const gchar *filename) {
 	g_free(path);
 	return file;
 }
-/*const gchar *full_path_utf8_from_uri(GFile *uri) {
-
-	GFileInfo* ginfo;
-	GError *error=NULL;
-	const gchar *utf8uri;
-	ginfo = g_file_query_info(uri, G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME, G_FILE_QUERY_INFO_NONE, NULL, &error);
-	utf8uri = g_file_info_get_display_name(ginfo);
-	g_object_unref(ginfo);
-	return utf8uri;
-}
-
-gchar *filename_utf8_from_uri(GFile *uri) {
-	gchar *utf8name, *slashpos;
-
-	utf8name = full_path_utf8_from_uri(uri);
-	slashpos = strrchr(utf8name,'/');
-	if (slashpos) {
-		gchar *tmp;
-		slashpos++;
-		tmp = g_strdup(slashpos);
-		g_free(utf8name);
-		return tmp;
-	}
-	return utf8name;
-}*/
-
-/*gchar *get_utf8filename_from_on_disk_encoding(const gchar *encodedname) {
-	if (encodedname) {
-		GError *gerror=NULL;
-		gsize b_written;
-		gchar *ondiskencoding = g_filename_to_utf8(encodedname,-1, NULL,&b_written,&gerror);
-		if (gerror) {
-			g_print(_("Bluefish has trouble reading the filenames. Try to set the environment variable G_BROKEN_FILENAMES=1\n"));
-			ondiskencoding = g_strdup(encodedname);
-		}
-		DEBUG_MSG("get_utf8filename_from_on_disk_encoding, utf8filename=%s\n",ondiskencoding);
-		return ondiskencoding;
-	}
-	return NULL;
-}*/
 
 gboolean string_is_color(const gchar *color) {
 	GdkColor gcolor;
@@ -840,37 +800,26 @@ gchar *trunc_on_char(gchar * string, gchar which_char)
 	}
 	return string;
 }
-/* gchar *strip_common_path(char *image_fn, char *html_fn)
- * returns a newly allocated string containing the the to_filename
- * but all the common path with from_filename is removed
- *
- * IS THIS IN USE ?? OBVIOUSLY NOT BECAUSE I CAN REMOVE IT */
-/*gchar *strip_common_path(char *to_filename, char *from_filename)
-{
-	gchar *tempstr;
-	int count, count2, dir_length;
 
-	count = 0;
-	tempstr = strrchr(to_filename, DIRCHR);
-	dir_length = strlen(to_filename) - strlen(tempstr);
-	dir_length += 1;
-	DEBUG_MSG("strip_common_path, dir_lenght=%d\n", dir_length);
-	while ((strncmp(to_filename, from_filename, count + 1)) == 0) {
-		count++;
-		if (count > dir_length) {
-			count = dir_length;
-			break;
-		}
+/**
+ * uri_from_external_input:
+ * @filename: a const gchar *with the string that should be a filename
+ * @reldiruri: a GFile * to a directory that might be the basedir is the output was a relative path
+ *
+ * if a filename is returned from an external command (such as in the outputbox or the
+ * generated bookmarks, this function can create a GFile* and returns that
+ * the caller should unref it
+ */
+GFile *uri_from_external_input(const gchar *filename, GFile *reldiruri) {
+	if (filename[0] == '/' || strchr(filename, ':') != NULL) {
+		/* absolute path, or a path with a uri */
+		/*g_print("return a value from g_file_new_for_commandline_arg(%s)\n",filename);*/ 
+		return g_file_new_for_commandline_arg(filename);
 	}
-	while (to_filename[count - 1] != DIRCHR)
-		count--;
-	DEBUG_MSG("strip_common_path, equal count = %d\n", count);
-	count2 = strlen(to_filename);
-	tempstr = g_malloc(count2 - count + 2);
-	memcpy(tempstr, &to_filename[count], count2 - count + 2);
-	DEBUG_MSG("strip_common_path, tempstr= %s, should be %d long\n", tempstr, count2 - count);
-	return tempstr;
-} */
+	/*g_print("return a value from g_file_resolve_relative_path()\n");*/
+	return g_file_resolve_relative_path(reldiruri, filename);
+}
+
 
 /**
  * most_efficient_filename:
