@@ -149,9 +149,7 @@ string_maintain_indenting(BluefishTextView * btv, gchar *string, gint *backward_
 		i++;
 	}
 	g_free(string);
-	string = gstr->str;
-	g_string_free(gstr, FALSE);
-	return string;
+	return g_string_free_and_steal(gstr);
 }
 
 /* returns the number of bytes
@@ -651,7 +649,7 @@ process_conditional_items(BluefishTextView * btv, Tfound *found, gint contextnum
 			}
 		}
 		if (valid) {
-			retval = g_list_prepend(retval, string);
+			retval = g_list_prepend(retval, (gpointer)(string));
 		}
 		
 		tmplist = tmplist->next;
