@@ -728,6 +728,7 @@ typedef struct {
 	Tbfwin *bfwin;
 	GtkWidget *menu;
 	GSList *group;
+	GSList *spelllangs; /* a list of strings */
 } Tdictlist;
 
 static void
@@ -735,19 +736,27 @@ list_dicts_lcb(const char *const lang_tag, const char *const provider_name, cons
 			   const char *const provider_file, void *data)
 {
 	Tdictlist *dl = data;
-	GtkWidget *menuitem;
-	DBG_SPELL("lang_tag=%s, provider_name=%s, provider_desc=%s, provider_file=%s\n",lang_tag,provider_name,provider_desc,provider_file);
-	menuitem = gtk_radio_menu_item_new_with_label(dl->group, lang_tag);
-	if (!dl->group)
-		dl->group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(menuitem));
-	if (g_strcmp0(dl->bfwin->session->spell_lang, lang_tag) == 0) {
-		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem), TRUE);
-	}
-	/*g_print("list_dicts_lcb, connect menuitem %p with group %p and label %s and bfwin %p to menu callback\n",menuitem, dl->group, lang_tag, dl->bfwin);*/
-	g_signal_connect(menuitem, "activate", G_CALLBACK(bftextview2_preferences_menu_lcb), dl->bfwin);
-	gtk_menu_shell_prepend(GTK_MENU_SHELL(dl->menu), GTK_WIDGET(menuitem));
+	dl->spelllangs = g_slist_prepend(dl->spelllangs, g_strdup((gpointer)lang_tag));
 }
 
+static void 
+add_dicts_to_menu(Tdictlist *dl) {
+	GSList *tmpslist = dl->spelllangs;
+	for (tmpslist = dl->spelllangs; tmpslist; tmpslist = tmpslist->next) {
+		const gchar *lang_tag = (const gchar *)tmpslist->data;
+		GtkWidget *menuitem;
+		menuitem = gtk_radio_menu_item_new_with_label(dl->group, lang_tag);
+		if (!dl->group)
+			dl->group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(menuitem));
+		if (g_strcmp0(dl->bfwin->session->spell_lang, lang_tag) == 0) {
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem), TRUE);
+		}
+		g_signal_connect(menuitem, "activate", G_CALLBACK(bftextview2_preferences_menu_lcb), dl->bfwin);
+		gtk_menu_shell_prepend(GTK_MENU_SHELL(dl->menu), GTK_WIDGET(menuitem));
+	}
+}
+
+
 static gboolean
 pure_ascii(const gchar * string)
 {
@@ -762,6 +771,11 @@ pure_ascii(const gchar * string)
 	return TRUE;
 }
 
+static gint
+spelllang_sort_func(gconstpointer a,gconstpointer b) {
+	return -1 * g_strcmp0((const gchar *)a, (const gchar *)b);
+}
+
 void
 bftextview2_populate_suggestions_popup(GtkMenu * menu, Tdocument * doc)
 {
@@ -788,7 +802,11 @@ bftextview2_populate_suggestions_popup(GtkMenu * menu, Tdocument * doc)
 	dl.bfwin = doc->bfwin;
 	dl.menu = submenu;
 	dl.group = NULL;
+	dl.spelllangs = NULL;
 	enchant_broker_list_dicts(eb, list_dicts_lcb, &dl);
+	dl.spelllangs = g_slist_sort(dl.spelllangs, spelllang_sort_func);
+	add_dicts_to_menu(&dl);
+	g_slist_free_full(dl.spelllangs, g_free);
 
 	if (!BFWIN(doc->bfwin)->ed)
 		return;
