@@ -306,6 +306,7 @@ typedef struct {
 	GList *external_command;	/* array: name,command,is_default_browser */
 	GList *external_filter;		/* array: name,command */
 	GList *external_outputbox;	/* array:name,command,....... */
+	GList *external_bookmarkcommands;	/* array:name,command,....... */
 	/*gint defaulthighlight; *//* highlight documents by default */
 	gint leave_to_window_manager;	/* don't set any dimensions, leave all to window manager */
 	gint restore_dimensions;	/* use the dimensions as used the previous run */
@@ -400,6 +401,7 @@ typedef struct {
 	gchar *print_fontstring;
 	gint bookmarks_default_store;	/* 0= temporary by default, 1= permanent by default */
 	gint bookmarks_follow_document;
+	gint bookmarks_follow_cursor;
 	gint image_thumbnail_refresh_quality;	/* 1=GDK_INTERP_BILINEAR, 0=GDK_INTERP_NEAREST */
 	gint image_thumbnailsizing_type;	/* scaling ratio=0, fixed width=1, height=2, width+height (discard aspect ratio)=3 */
 	gint image_thumbnailsizing_val1;	/* the width, height or ratio, depending on the value above */
@@ -441,6 +443,7 @@ typedef struct {
 	gint snr3_escape_chars;
 	gint snr3_dotmatchall;
 	gint snr3_recursion_level;
+	gint snr3_bookmarkpermanent;
 	/* simplesearch options */
 	gint ssearch_regex;
 	gint ssearch_dotmatchall;
@@ -470,7 +473,7 @@ typedef struct {
 	gint convertcolumn_horizontally;
 	gint display_right_margin;
 	gint show_visible_spacing;
-	/* 48 * sizeof(gint) */
+	/* 49 * sizeof(gint) */
 	/* IF YOU EDIT THIS STRUCTURE PLEASE EDIT THE CODE IN PROJECT.C THAT COPIES
 	   A Tsessionvar INTO A NEW Tsessionvar in project_setup_initial_session() 
 	   AND ADJUST THE SIZES!!!!!!!!!!!!!!!!!!!!!! */
@@ -593,6 +596,8 @@ typedef struct {
 	GtkActionGroup *recent_group;
 	GtkActionGroup *fb2_filters_group;
 	guint fb2_filters_merge_id;
+	GtkActionGroup *extbookmark_group;
+	guint extbookmark_merge_id;
 #ifdef HAVE_LIBENCHANT
 	gpointer *ed;				/* EnchantDict */
 #endif
