@@ -159,8 +159,8 @@ split_lines_backend(Tdocument * doc, gint start, gint end)
 			if (starti == endi || endi==-1) {
 				new_indenting = g_strdup("\n");
 			} else {
-				tmp1 = buf+utf8_byteoffset_to_charsoffset_cached(buf, starti-start);
-				tmp2 = buf+utf8_byteoffset_to_charsoffset_cached(buf, endi-start);
+				tmp1 = buf+utf8_charoffset_to_byteoffset_cached(buf, starti-start);
+				tmp2 = buf+utf8_charoffset_to_byteoffset_cached(buf, endi-start);
 				/*tmp1 = g_utf8_offset_to_pointer(buf, starti-start);
 				tmp2 = g_utf8_offset_to_pointer(buf, endi-start);*/
 				new_indenting = g_strndup(tmp1, (tmp2 - tmp1));
