@@ -133,7 +133,7 @@ files_advanced_win_select_basedir_lcb(GtkWidget * widget, Tfiles_advanced * tfs)
 void
 files_advanced_win(Tbfwin * bfwin, gchar * basedir)
 {
-	GtkWidget *alignment, *button, *carea, *table, *vbox, *vbox2;
+	GtkWidget *alignment, *carea, *table, *vbox, *vbox2;
 	Tfiles_advanced *tfs;
 
 	tfs = g_new(Tfiles_advanced, 1);
@@ -167,8 +167,7 @@ files_advanced_win(Tbfwin * bfwin, gchar * basedir)
 	}
 	dialog_mnemonic_label_in_table(_("Base _Dir:"), tfs->basedir, table, 0, 1, 0, 1);
 
-	button =
-		dialog_button_new_with_image_in_table(NULL, GTK_STOCK_OPEN, G_CALLBACK(files_advanced_win_select_basedir_lcb), tfs,
+	dialog_button_new_with_image_in_table(NULL, GTK_STOCK_OPEN, G_CALLBACK(files_advanced_win_select_basedir_lcb), tfs,
 						TRUE, FALSE,
 						table, 5, 6, 0,1);
 
@@ -591,7 +590,6 @@ gchar *
 ask_new_filename(Tbfwin * bfwin, const gchar * old_curi, const gchar *dialogtext)
 {
 	Tdocument *exdoc;
-	GList *alldocs;
 	gchar *new_curi = NULL;
 	GFile *uri;
 	GtkWidget *dialog;
@@ -1071,7 +1069,6 @@ void
 doc_save_all_close(Tbfwin * bfwin)
 {
 	GList *tmplist, *duplist;
-	Tdocument *tmpdoc;
 	duplist = g_list_copy(bfwin->documentlist); /* Copy ducumentlist first, since using just tmplist causes unexpected behavior as docs are destroyed */
 	tmplist = g_list_first(duplist);
 	while (tmplist) {
