@@ -272,7 +272,7 @@ static const linguas_t linguas[] = {
 
 #ifdef HAVE_LINGUA_KO_KR
 	{
-		N_("Korean"), "Korean",
+		N_("Korean"), "한국어",
 #ifdef WIN32
 		LANG_KOREAN, SUBLANG_KOREAN,
 #endif /* WIN32 */
