@@ -242,7 +242,7 @@ about_dialog_create(GtkAction * action, gpointer user_data)
 		"Rasmus Toftdahl Olesen <rto@pohldata.dk>",
 		"Roland Steinbach <roland@netzblick.de>",
 		"Santiago Capel Torres",
-		"Shawn Novak <kernel86@gmail.com>",
+		"Hannah Novak <kernel86@gmail.com>",
 		"Yanike Mann <yanikem@gmail.com>",
 /*		_("\nPackage maintainers:"),*/
 		"Debian: Daniel Leidert <daniel.leidert@wgdd.de>",
@@ -250,7 +250,7 @@ about_dialog_create(GtkAction * action, gpointer user_data)
 		"Gentoo: Hanno Böck <hanno@gentoo.org>",
 		"Mandrake: Todd Lyons <todd@mrball.net>",
 		"Redhat: Matthias Haase <matthias_haase@bennewitz.com>",
-		"Windows: Shawn Novak <kernel86@gmail.com>, Daniel Leidert <daniel.leidert@wgdd.de>",
+		"Windows: Hannah Novak <kernel86@gmail.com>, Daniel Leidert <daniel.leidert@wgdd.de>",
 		_("\nIf you know of anyone missing from this list,\nplease let us know at:"),
 		_("bluefish@bluefish.openoffice.nl <bluefish@bluefish.openoffice.nl>"),
 		_("\nThanks to all who helped make this software available.\n"),
