@@ -460,7 +460,7 @@ htmlbar_insert_form_fieldset_tag(GtkAction * action, gpointer user_data)
 static void
 htmlbar_insert_form_legend_tag(GtkAction * action, gpointer user_data)
 {
-	doc_insert_two_strings(BFWIN(user_data)->current_document, cap("<LEGEND>"), cap("<LEGEND/>"));
+	doc_insert_two_strings(BFWIN(user_data)->current_document, cap("<LEGEND>"), cap("</LEGEND>"));
 }
 
 static void
