@@ -373,7 +373,7 @@ static void parse_tagstring(Tbfwin *bfwin, gchar * tagstring, gint pos, gint end
 	gint i, numitems = (sizeof(tagdia)/sizeof(Ttagdialog));
 		for (i=0;i<numitems;i++) {
 			if (strcmp(tmpstring, tagdia[i].tag) == 0) {
-				tagdia[i].func(bfwin, tag_popup);
+				((void (*)(Tbfwin *, Ttagpopup *))tagdia[i].func)(bfwin, tag_popup);
 				break;
 			}
 		}
