@@ -99,9 +99,9 @@ static GHashTable *return_colorprofile_configlist(GHashTable *config_rc,  gboole
 
 
 static void
-free_configlist(GHashTable * configlist)
+free_configlist(GHashTable * hasht)
 {
-	g_hash_table_destroy(configlist);
+	g_hash_table_destroy(hasht);
 }
 
 static void
@@ -112,21 +112,23 @@ free_config_list_item(gpointer data)
 
 /*this should add 1 empty entry to the configuration list */
 GHashTable *
-make_config_list_item(GHashTable * config_list, void *pointer_to_var, unsigned char type_of_var,
+make_config_list_item(GHashTable * config_hasht, void *pointer_to_var, unsigned char type_of_var,
 					  gchar * name_of_var, gint len)
 {
 	Tconfig_list_item *config_list_item;
 	if (!pointer_to_var) {
 		DEBUG_MSG("make_config_list_item, pointer to var = NULL !\n");
-		return config_list;
+		return config_hasht;
 	}
 	config_list_item = g_slice_new(Tconfig_list_item);
 	config_list_item->pointer = pointer_to_var;
 	config_list_item->type = type_of_var;
 	config_list_item->identifier = name_of_var;
 	config_list_item->len = len;
-	g_hash_table_replace(config_list, name_of_var, config_list_item);
-	return config_list;
+	/*g_print("make_config_list_item, call g_hash_table_replace() for hashtable %p with name %s and config_list_item=%p var pointer=%p\n",config_hasht,name_of_var,config_list_item, pointer_to_var);*/
+	g_hash_table_replace(config_hasht, name_of_var, config_list_item);
+	/*g_print("return hashtable %p\n",config_hasht);*/
+	return config_hasht;
 }
 
 static void
@@ -412,7 +414,7 @@ props_init_main(GHashTable * config_rc)
 	init_prop_string(&config_rc, &main_v->props.config_version, "config_version:", "2.2.7");
 	init_prop_integer(&config_rc, &main_v->props.check_for_modified_on_disk, "check_for_modified_on_disk:", 1, TRUE);
 #ifdef MAC_INTEGRATION
-	init_prop_string(&config_rc, &main_v->props.editor_font_string, "editor_font_string:", "Lucida Grande 13");
+	init_prop_string(&config_rc, &main_v->props.editor_font_string, "editor_font_string:", "Monospace Regular 13");
 #else
 	init_prop_string(&config_rc, &main_v->props.editor_font_string, "editor_font_string:", "monospace 10");
 #endif
@@ -429,6 +431,7 @@ props_init_main(GHashTable * config_rc)
 	init_prop_arraylist(&config_rc, &main_v->props.external_command, "external_command:", 0, TRUE);
 	init_prop_arraylist(&config_rc, &main_v->props.external_filter, "external_filter:", 0, TRUE);
 	init_prop_arraylist(&config_rc, &main_v->props.external_outputbox, "external_outputbox:", 0, TRUE);
+	init_prop_arraylist(&config_rc, &main_v->props.external_bookmarkcommands, "external_bookmarkcommands:", 0, TRUE);
 
 	/*init_prop_integer   (&config_rc, &main_v->props.defaulthighlight, "defaulthighlight:", 1, TRUE); */
 	/* old type filetypes have a different count, they are converted below */
@@ -703,7 +706,13 @@ static GList *update_externals(GList *current, GList *defaults, gboolean overwri
 		g_hash_table_destroy(ht);
 	return current;
 }
-
+/* the array has 4 elements:
+ - the regex
+ - the regex group number that has the filename
+ - the regex group number that has the line number
+ - the regex group number that has the output
+ - the command to execute
+ */
 GList * update_outputbox(GList *current, gboolean overwrite) {
 	GList *defaults = NULL, *retlist;
 	DEBUG_MSG("update_outputbox, started\n");
@@ -754,14 +763,28 @@ GList * update_outputbox(GList *current, gboolean overwrite) {
 										 "1", "2", "phpcs --report=emacs '%f'|", NULL));
 	defaults =
 		g_list_append(defaults,
-						array_from_arglist(_("pylint"), "(C|R|E|F|W):[ ]*([0-9]+),[0-9]+:(.*)", "-1",
-										 "2", "0", "pylint '%f'|", NULL));
+						array_from_arglist(_("pylint"), "([^:]+):([0-9]+):[0-9]+:(.*)", "1",
+										 "2", "3", "pylint '%f'|", NULL));
+	defaults =
+		g_list_append(defaults,
+						array_from_arglist(_("ctags"), "([^\\t ]+[ \\t]+[^\\t ]+[ \\t]+)([0-9]+)[ \\t]+([^ \\t]+)(.*)", "3",
+										 "2", "4", "ctags -xu '%f'|", NULL));
 #endif
 	retlist = update_externals(current, defaults, overwrite, 7, 6);
 	free_arraylist(defaults);
 	return retlist;
 }
 
+GList *update_bookmarkcommands(GList *current, gboolean overwrite) {
+	GList *defaults = NULL, *retlist;
+	defaults = g_list_append(defaults,
+						array_from_arglist(_("Generate from ctags"), "([^\\t ]+[ \\t]+[^\\t ]+[ \\t]+)([0-9]+)[ \\t]+([^ \\t]+)(.*)", "3",
+										 "2", "4", "ctags -xu --kinds-c=ft --kinds-Python=cfm --kinds-PHP=cf '%f'|", "#444477", NULL));
+	retlist = update_externals(current, defaults, overwrite, 8, 7);
+	free_arraylist(defaults);
+	return retlist;
+}
+
 GList *update_filters(GList *current, gboolean overwrite)
 {
 	GList *defaults=NULL, *retlist;
@@ -796,6 +819,9 @@ GList *update_filters(GList *current, gboolean overwrite)
 	defaults =
 		g_list_append(defaults,
 					  array_from_arglist(_("JSON Beautifier"), "|"PKGDATADIR"/json_prettyprint.py|", NULL));
+	defaults =
+		g_list_append(defaults,
+					  array_from_arglist(_("js-beautify "), "|js-beautify -t -n|", NULL));
 #ifdef WIN32
 	defaults =
 		g_list_append(defaults,
@@ -944,6 +970,15 @@ rcfile_parse_main(void)
 		main_v->props.external_filter = update_filters(main_v->props.external_filter, FALSE);
 		main_v->props.external_outputbox = update_outputbox(main_v->props.external_outputbox, FALSE);
 	}
+	if (!main_v->props.external_command)
+		main_v->props.external_command = update_commands(main_v->props.external_command, TRUE);
+	if (!main_v->props.external_filter)
+		main_v->props.external_filter = update_filters(main_v->props.external_filter, TRUE);
+	if (!main_v->props.external_outputbox)
+		main_v->props.external_outputbox = update_outputbox(main_v->props.external_outputbox, FALSE);
+	if (!main_v->props.external_bookmarkcommands)
+		main_v->props.external_bookmarkcommands = update_bookmarkcommands(main_v->props.external_bookmarkcommands, FALSE);	
+	
 #ifdef OLDTEMPLATES
 	if (main_v->props.templates == NULL) {
 		main_v->props.templates =
@@ -1233,7 +1268,9 @@ return_globalsession_configlist(gboolean init_values)
 	init_prop_integer(&config_rc, &main_v->globses.bookmarks_default_store, "bookmarks_default_store:", 1,
 					  init_values);
 	init_prop_integer(&config_rc, &main_v->globses.bookmarks_follow_document, "bookmarks_follow_document:", 1,
-					  init_values);	
+					  init_values);
+	init_prop_integer(&config_rc, &main_v->globses.bookmarks_follow_cursor, "bookmarks_follow_cursor:", 1,
+					  init_values);
 	init_prop_integer(&config_rc, &main_v->globses.image_thumbnail_refresh_quality,
 					  "image_thumbnail_refresh_quality:", 1, init_values);
 	init_prop_integer(&config_rc, &main_v->globses.image_thumbnailsizing_type, "image_thumbnailsizing_type:",
@@ -1293,6 +1330,7 @@ return_session_configlist(GHashTable * configlist, Tsessionvars * session)
 	init_prop_integer(&configlist, &session->snr3_escape_chars, "snr_escape_chars:", 1, FALSE);
 	init_prop_integer(&configlist, &session->snr3_dotmatchall, "snr_dotmatchall:", 1, FALSE);
 	init_prop_integer(&configlist, &session->snr3_recursion_level, "snr_recursion_level:", 5, FALSE);
+	init_prop_integer(&configlist, &session->snr3_bookmarkpermanent, "snr_bookmarkpermanent:", 0, FALSE);
 
 	init_prop_integer(&configlist, &session->ssearch_regex, "ssearch_regex:", 0, FALSE);
 	init_prop_integer(&configlist, &session->ssearch_dotmatchall, "ssearch_dotmatchall:", 0, FALSE);
@@ -1626,6 +1664,7 @@ void props_free()
 	free_arraylist(external_command);
 	free_arraylist(external_filter);
 	free_arraylist(external_outputbox);
+	free_arraylist(external_bookmarkcommands);
 	g_free(main_v->props.image_thumbnailstring);
 	g_free(main_v->props.image_thumbnailtype);
 	g_free(main_v->props.newfile_default_encoding);
